# Automatically Generated Files

This folder contains files that are automatically generated by the build script
and might be shared between multiple crates in the workspace.

Currently, it is used to build a public API map to be used by our wrapper crates.
The API map is generated by build.rs into generated/api_map.rs and is consumed by the docs export pipeline and bindings.

Do not edit files in this folder manually.
